@@ -1,12 +1,15 @@
 package MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize;
 # ABSTRACT: A custom meta-attribute-trait to bypass serialization
-our $VERSION = '0.49';
+
+our $VERSION = '0.52';
+
 use Moose::Role;
 use namespace::autoclean;
 
 # register this alias ...
-package Moose::Meta::Attribute::Custom::Trait::DoNotSerialize;
-our $VERSION = '0.49';
+package # hide from PAUSE
+    Moose::Meta::Attribute::Custom::Trait::DoNotSerialize;
+
 sub register_implementation { 'MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize' }
 
 1;
@@ -23,7 +26,7 @@ MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize - A custom meta-attribut
 
 =head1 VERSION
 
-version 0.49
+version 0.52
 
 =head1 SYNOPSIS
 
@@ -53,21 +56,16 @@ serialization, in this case, you want to make sure that attribute
 uses this custom meta-attribute-trait. See the SYNOPSIS for a nice
 example that can be easily cargo-culted.
 
-=head1 METHODS
+=head1 SUPPORT
 
-=head2 Introspection
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Storage>
+(or L<bug-MooseX-Storage@rt.cpan.org|mailto:bug-MooseX-Storage@rt.cpan.org>).
 
-=over 4
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
 
-=item B<meta>
-
-=back
-
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHORS
 
@@ -89,7 +87,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2007 by Infinity Interactive, Inc..
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
